use strict;
use warnings;
package App::Pastebin::Create;

#ABSTRACT: Create and upload paste to pastebin (DOCUMENTATION IN DEVELOPMENT)
# FILE HOLDER/THIS IS COMMAND LINE APP, executable name is pastebin-create
# type pastebin -h for usage
1;
